"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ast_1 = require("../utils/ast");
function isTestGroup(node) {
    const testGroups = new Set(['describe', 'parallel', 'serial']);
    return (node.object.type === 'MemberExpression' &&
        node.object.property.type === 'Identifier' &&
        testGroups.has(node.object.property.name));
}
exports.default = {
    create(context) {
        return {
            MemberExpression(node) {
                if (((0, ast_1.isTestIdentifier)(node) || isTestGroup(node)) &&
                    (0, ast_1.isIdentifier)(node.property, 'only')) {
                    const range = node.property.range;
                    context.report({
                        messageId: 'noFocusedTest',
                        suggest: [
                            {
                                messageId: 'removeFocusedTestAnnotation',
                                // - 1 to remove the `.only` annotation with dot notation
                                fix: (fixer) => fixer.removeRange([range[0] - 1, range[1]]),
                            },
                        ],
                        node,
                    });
                }
            },
        };
    },
    meta: {
        docs: {
            category: 'Possible Errors',
            description: 'Prevent usage of `.only()` focus test annotation',
            recommended: true,
            url: 'https://github.com/playwright-community/eslint-plugin-playwright/tree/main/docs/rules/no-focused-test.md',
        },
        hasSuggestions: true,
        messages: {
            noFocusedTest: 'Unexpected use of .only() annotation.',
            removeFocusedTestAnnotation: 'Remove .only() annotation',
        },
        type: 'problem',
    },
};
