"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ast_1 = require("../utils/ast");
const matcherMap = {
    toBeVisible: 'toBeHidden',
    toBeHidden: 'toBeVisible',
    toBeEnabled: 'toBeDisabled',
    toBeDisabled: 'toBeEnabled',
};
exports.default = {
    create(context) {
        return {
            MemberExpression(node) {
                if (node.object.type === 'MemberExpression' &&
                    node.object.object.type === 'CallExpression' &&
                    (0, ast_1.isIdentifier)(node.object.object.callee, 'expect') &&
                    (0, ast_1.isIdentifier)(node.object.property, 'not')) {
                    const matcher = (0, ast_1.getNodeName)(node.property);
                    if (matcher && matcher in matcherMap) {
                        const range = node.object.property.range;
                        context.report({
                            fix: (fixer) => [
                                fixer.removeRange([range[0], range[1] + 1]),
                                fixer.replaceText(node.property, matcherMap[matcher]),
                            ],
                            messageId: 'noUselessNot',
                            node: node,
                            data: {
                                old: matcher,
                                new: matcherMap[matcher],
                            },
                        });
                    }
                }
            },
        };
    },
    meta: {
        docs: {
            category: 'Best Practices',
            description: `Disallow usage of 'not' matchers when a more specific matcher exists`,
            recommended: true,
            url: 'https://github.com/playwright-community/eslint-plugin-playwright/tree/main/docs/rules/no-useless-not.md',
        },
        fixable: 'code',
        messages: {
            noUselessNot: 'Unexpected usage of not.{{old}}(). Use {{new}}() instead.',
        },
        type: 'problem',
    },
};
