"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPropertyAccessor = exports.getMatchers = exports.isExpectCall = exports.isTestHook = exports.isTest = exports.findParent = exports.isDescribeCall = exports.isBooleanLiteral = exports.isStringLiteral = exports.isObjectProperty = exports.isTestIdentifier = exports.isCalleeProperty = exports.isObject = exports.isIdentifier = exports.getNodeName = exports.getStringValue = void 0;
function getStringValue(node) {
    return node.type === 'TemplateLiteral'
        ? node.quasis[0].value.raw
        : node.type === 'Literal' && typeof node.value === 'string'
            ? node.value
            : '';
}
exports.getStringValue = getStringValue;
function getNodeName(node) {
    return node.type === 'Identifier' ? node.name : undefined;
}
exports.getNodeName = getNodeName;
function isIdentifier(node, name) {
    return getNodeName(node) === name;
}
exports.isIdentifier = isIdentifier;
function isObject(node, name) {
    return (node.callee.type === 'MemberExpression' &&
        isIdentifier(node.callee.object, name));
}
exports.isObject = isObject;
function isCalleeProperty(node, name) {
    return (node.callee.type === 'MemberExpression' &&
        isIdentifier(node.callee.property, name));
}
exports.isCalleeProperty = isCalleeProperty;
function isTestIdentifier(node) {
    return (isIdentifier(node, 'test') ||
        (node.type === 'MemberExpression' && isIdentifier(node.object, 'test')));
}
exports.isTestIdentifier = isTestIdentifier;
function isObjectProperty(node, name) {
    return (node.object.type === 'MemberExpression' &&
        isIdentifier(node.object.property, name));
}
exports.isObjectProperty = isObjectProperty;
function isLiteral(node, type, value) {
    return (node.type === 'Literal' &&
        (value === undefined
            ? typeof node.value === type
            : node.value === value));
}
function isStringLiteral(node, value) {
    return isLiteral(node, 'string', value);
}
exports.isStringLiteral = isStringLiteral;
function isBooleanLiteral(node, value) {
    return isLiteral(node, 'boolean', value);
}
exports.isBooleanLiteral = isBooleanLiteral;
const describeProperties = new Set([
    'parallel',
    'serial',
    'only',
    'skip',
    'fixme',
]);
function isDescribeProperty(node) {
    return describeProperties.has(getNodeName(node) ?? '');
}
function isDescribeCall(node) {
    const inner = node.type === 'CallExpression' ? node.callee : node;
    // Allow describe without test prefix
    if (isIdentifier(inner, 'describe')) {
        return true;
    }
    if (inner.type !== 'MemberExpression') {
        return false;
    }
    return isIdentifier(inner.property, 'describe')
        ? true
        : isDescribeProperty(inner.property)
            ? isDescribeCall(inner.object)
            : false;
}
exports.isDescribeCall = isDescribeCall;
function findParent(node, type) {
    if (!node.parent)
        return;
    return node.parent.type === type
        ? node.parent
        : findParent(node.parent, type);
}
exports.findParent = findParent;
function isTest(node) {
    return (isTestIdentifier(node.callee) &&
        !isDescribeCall(node) &&
        node.arguments.length === 2 &&
        ['ArrowFunctionExpression', 'FunctionExpression'].includes(node.arguments[1].type));
}
exports.isTest = isTest;
const testHooks = new Set(['afterAll', 'afterEach', 'beforeAll', 'beforeEach']);
function isTestHook(node) {
    return (node.callee.type === 'MemberExpression' &&
        isIdentifier(node.callee.object, 'test') &&
        node.callee.property.type === 'Identifier' &&
        testHooks.has(node.callee.property.name));
}
exports.isTestHook = isTestHook;
const expectSubCommands = new Set(['soft', 'poll']);
function isExpectCall(node) {
    return (isIdentifier(node.callee, 'expect') ||
        (node.callee.type === 'MemberExpression' &&
            isIdentifier(node.callee.object, 'expect') &&
            node.callee.property.type === 'Identifier' &&
            expectSubCommands.has(node.callee.property.name)));
}
exports.isExpectCall = isExpectCall;
function getMatchers(node, chain = []) {
    if (node.parent.type === 'MemberExpression' && node.parent.object === node) {
        return getMatchers(node.parent, [...chain, node.parent.property]);
    }
    return chain;
}
exports.getMatchers = getMatchers;
function isPropertyAccessor(node, name) {
    return (isIdentifier(node.property, name) || isStringLiteral(node.property, name));
}
exports.isPropertyAccessor = isPropertyAccessor;
